import { ConfigService } from '@agiliza/curio/SessionManager'
import { createSlice, PayloadAction } from '@reduxjs/toolkit'

export interface State {
  initializing: boolean
  authenticating: boolean
  authenticated: boolean
  error?: string
  serviceInfo?: ConfigService
}

export const initialState: State = {
  authenticated: false,
  authenticating: false,
  initializing: false,
}

export type Actions = 'setServiceInfo' | 'authRequest' | 'authSuccess' | 'authError' | 'logout' | 'logoutSuccess'

const session = createSlice({
  name: 'session',
  initialState,
  reducers: {
    initialize: (state) => {
      state.initializing = true
    },
    initializeSuccess: (state) => {
      state.initializing = false
    },
    initializeError: (state, action: PayloadAction<string | undefined>) => {
      state.initializing = false
      state.error = action.payload
    },
    authRequest: (state) => {
      state.authenticating = true
      state.error = undefined
    },
    authSuccess: (state) => {
      state.authenticating = false
      state.authenticated = true
    },
    authError: (state, action: PayloadAction<string | undefined>) => {
      state.authenticating = false
      state.error = action.payload
    },
    logout: (state) => {
      state.error = undefined
    },
    logoutSuccess: (state) => {
      state.authenticated = false
    },
    setServiceInfo: (state, action: PayloadAction<ConfigService>) => {
      state.serviceInfo = action.payload
    },
  },
})

export default session
