import React, { lazy, Suspense, useEffect } from 'react'
import { Redirect, Route, RouteComponentProps, Switch, useLocation } from 'react-router'

import AppBar from '@agiliza/components/molecules/AppBar'
import CircularProgress from '@agiliza/components/molecules/CircularProgress'
import Drawer from '@agiliza/components/molecules/Drawer'
import { actions as sessionActions } from '@agiliza/redux/session'
import { actions as drawerActions } from '@agiliza/redux/ui/drawer'
import { withStyles, WithStyles } from '@material-ui/core/styles'

import connect, { ConnectedProps } from './connect'
import DrawerItems, { mapPathToTitle, PATHS } from './DrawerItems'
import styles from './styles'

const SimulationCreditLines = lazy(() => import('@agiliza/views/SimulationCreditLines/pages/router'))
// const SecurityProfile = lazy(() => import('@curio/ui/dist/views/SecurityProfile'))

type BaseProps = RouteComponentProps & ConnectedProps & WithStyles<typeof styles>

interface Props extends BaseProps {
  toggleDrawer: typeof drawerActions.toggleDrawer
  logout: typeof sessionActions.logout
}

const Main = (props: Props) => {
  const { classes, drawerOpen, toggleDrawer, logout, fetchMenu, ...routeProps } = props

  const { pathname } = useLocation()

  useEffect(() => {
    fetchMenu()
  }, [])

  return (
    <div className={classes.pageContainer}>
      <AppBar
        onNavClick={toggleDrawer}
        title={<div className={classes.title}>{mapPathToTitle(pathname.substring(0, pathname.lastIndexOf('/')))}</div>}
      ></AppBar>
      <Drawer drawerOpen={drawerOpen} toggleDrawer={toggleDrawer} logout={logout} Items={DrawerItems} {...routeProps} />
      <Suspense fallback={<CircularProgress />}>
        <Switch>
          <Route path={PATHS.creditLines} render={(rProps) => <SimulationCreditLines {...rProps} />} />
          <Redirect from="/" to={PATHS.creditLines} />
        </Switch>
      </Suspense>
    </div>
  )
}

export default connect(withStyles(styles)(Main))
