import React from 'react'

import { Slider, SliderProps, TextField, TextFieldProps, Typography } from '@material-ui/core'

type ExtendedProps = Record<string, unknown>

interface Props extends ExtendedProps {
  title: string
  min: SliderProps['min']
  max: SliderProps['max']
  marks?: SliderProps['marks']
  valueSlider: number
  valueField: string
  step?: SliderProps['step']
  onChangeSlider: (event: React.ChangeEvent<Record<string, unknown>>, value: number | number[]) => void
  onChangeField: TextFieldProps['onChange']
  onBlurField: TextFieldProps['onBlur']
  disabled: boolean
  className?: string
}

const SliderField = (props: Props) => {
  const { className, title, min, max, marks, valueSlider, valueField, step = 1, disabled, onChangeSlider, onChangeField, onBlurField } = props
  return (
    <div className={className}>
      <Typography gutterBottom>{title}</Typography>
      <Slider
        disabled={disabled}
        min={min}
        max={max}
        value={valueSlider}
        onChange={onChangeSlider}
        // valueLabelDisplay="auto"
        step={step}
        marks={marks}
      />
      <TextField style={{ width: '12%' }} disabled={disabled} value={valueField} onChange={onChangeField} onBlur={onBlurField} />
    </div>
  )
}

export default SliderField
