import React, { useEffect, useMemo } from 'react'

import { formatCurrency } from '@agiliza/utils/formatters'
import { Grid } from '@material-ui/core'
import { withStyles, WithStyles } from '@material-ui/core/styles'

import { creditLinesData } from '../../../../../__mocks__/creditLines'
import GridLine from './GridLine'
import styles from './styles'

type ExtendedProps = WithStyles<typeof styles>

interface Props extends ExtendedProps {
  id: string
  onChangeCanGoForward: (vl: boolean) => void
}

const CreditLinesInfo = (props: Props) => {
  const { classes, id, onChangeCanGoForward } = props

  const creditLine = useMemo(() => creditLinesData[id], [id])

  useEffect(() => {
    onChangeCanGoForward(true)
  }, [])

  return (
    <div className={classes.contentContainer}>
      <div className={classes.content}>
        <Grid container className={classes.gridContainer}>
          <GridLine label="Número de parcelas" value={creditLine?.paymentMonths} />
          <GridLine label="Valor das parcelas" value={formatCurrency(creditLine?.amount.toFixed(2))} />
          <GridLine label="Taxa de juros" value={`${creditLine?.interestRate} %`} />
          <GridLine label="Custo efetivo total (CET)" value={`${creditLine?.effectiveTotalCost} %`} />
          <GridLine label="Taxa abertura crédito (TAC)" value={formatCurrency(creditLine?.openingCreditRate.toFixed(2))} />
        </Grid>
      </div>
    </div>
  )
}

export default withStyles(styles)(CreditLinesInfo)
