import React, { useMemo, useState } from 'react'
import { RouteComponentProps, useLocation } from 'react-router'

import { PATHS } from '@agiliza/views/Main/DrawerItems'
import { Button, Step, StepLabel, Stepper } from '@material-ui/core'
import { withStyles, WithStyles } from '@material-ui/core/styles'
import {
  KeyboardArrowLeft as KeyboardArrowLeftIcon,
  KeyboardArrowRight as KeyboardArrowRightIcon
} from '@material-ui/icons'

import CreditLinesInfo from './CreditLinesInfo'
import styles from './styles'
import UserForm from './UserForm'
import VerificationCode from './VerificationCode'

type ExtendedProps = WithStyles<typeof styles> & RouteComponentProps

interface Props extends ExtendedProps {}

const Simulation = (props: Props) => {
  const { classes, history } = props
  // const theme = useTheme()
  const { state: lState } = useLocation<{ id: string }>()
  const [activeStep, setActiveStep] = useState(0)
  const [canGoForward, setCanGoForward] = useState(true)

  const handleChangeCanGoForward = (value: boolean) => {
    setCanGoForward(value)
  }

  const renderStep = (step: number) => {
    switch (step) {
      case 0:
        return <CreditLinesInfo id={lState.id} onChangeCanGoForward={handleChangeCanGoForward} />
      case 1:
        return <UserForm onChangeCanGoForward={handleChangeCanGoForward} />
      case 2:
        return <VerificationCode onChangeCanGoForward={handleChangeCanGoForward} />
    }
  }

  const handleNext = () => {
    if (activeStep === steps - 1) history.push({ pathname: PATHS.creditLines })
    else setActiveStep((prevActiveStep) => prevActiveStep + 1)
  }

  const handleBack = () => {
    setActiveStep((prevActiveStep) => prevActiveStep - 1)
  }

  const steps = useMemo(() => 3, [])

  return (
    <div className={classes.pageContent}>
      <div className={classes.stepContentContainer}>{renderStep(activeStep)}</div>
      <div className={classes.stepperContainer}>
        <Button size="large" onClick={handleBack} disabled={activeStep === 0} className={classes.stepperBtn}>
          <KeyboardArrowLeftIcon />
          Anterior
        </Button>
        <Stepper activeStep={activeStep} alternativeLabel className={classes.stepper}>
          <Step>
            <StepLabel>Informações linha de crédito</StepLabel>
          </Step>
          <Step>
            <StepLabel>Dados pessoais</StepLabel>
          </Step>
          <Step>
            <StepLabel>Código de verificação</StepLabel>
          </Step>
        </Stepper>
        <Button size="large" onClick={handleNext} disabled={!canGoForward} className={classes.stepperBtn}>
          {activeStep === steps - 1 ? (
            'Finalizar'
          ) : (
            <>
              Próximo
              <KeyboardArrowRightIcon />
            </>
          )}
        </Button>
        {/* <MobileStepper
          variant="dots"
          steps={steps}
          position="static"
          activeStep={activeStep}
          className={classes.stepper}
          nextButton={
            <Button size="small" onClick={handleNext} disabled={!canGoForward || activeStep === steps}>
              Próximo
              <KeyboardArrowRightIcon />
            </Button>
          }
          backButton={
            <Button size="small" onClick={handleBack} disabled={!canGoBackward || activeStep === 0}>
              <KeyboardArrowLeftIcon />
              Anterior
            </Button>
          }
        /> */}
      </div>
    </div>
  )
}

export default withStyles(styles)(Simulation)
