import React, { useEffect, useState } from 'react'

import { extractNumbers } from '@agiliza/utils/extractors'
import { TextField, TextFieldProps, Typography } from '@material-ui/core'
import { withStyles, WithStyles } from '@material-ui/core/styles'

import styles from './styles'

type ExtendedProps = WithStyles<typeof styles>

interface Props extends ExtendedProps {
  onChangeCanGoForward: (vl: boolean) => void
}

const VerificationCode = (props: Props) => {
  const { classes, onChangeCanGoForward } = props

  const [code, setCode] = useState('')

  useEffect(() => {
    onChangeCanGoForward(code.length === 6)
  }, [code])

  const handleChange: TextFieldProps['onChange'] = (evt) => {
    setCode(extractNumbers(evt.target.value))
  }

  return (
    <div className={classes.contentContainer}>
      <div className={classes.content}>
        <Typography variant="h5">Foi enviado um código de verificação por email.</Typography>
        <TextField
          label="Código de verificação"
          value={code}
          onChange={handleChange}
          variant="outlined"
          className={classes.codeField}
          inputProps={{ maxLength: 6 }}
        />
      </div>
    </div>
  )
}

export default withStyles(styles)(VerificationCode)
